@@ -31,6 +31,7 @@
 #include <pipewire/extensions/metadata.h>
 
 #include "log.h"
+#include "module-protocol-pulse/server.h"
 
 #define MAX_PARAMS 32
 
@@ -39,6 +40,7 @@
 #define manager_emit_updated(m,o) spa_hook_list_call(&m->hooks, struct pw_manager_events, updated, 0, o)
 #define manager_emit_removed(m,o) spa_hook_list_call(&m->hooks, struct pw_manager_events, removed, 0, o)
 #define manager_emit_metadata(m,o,s,k,t,v) spa_hook_list_call(&m->hooks, struct pw_manager_events, metadata,0,o,s,k,t,v)
+#define manager_emit_disconnect(m) spa_hook_list_call(&m->hooks, struct pw_manager_events, disconnect, 0)
 
 struct object;
 
@@ -165,8 +167,6 @@ static struct object *find_object(struct manager *m, uint32_t id)
 {
 	struct object *o;
 	spa_list_for_each(o, &m->this.object_list, this.link) {
-		if (o->this.creating)
-			continue;
 		if (o->this.id == id)
 			return o;
 	}
@@ -643,7 +643,8 @@ static void registry_event_global_remove(void *object, uint32_t id)
 
 	o->this.removing = true;
 
-	manager_emit_removed(m, &o->this);
+	if (!o->this.creating)
+		manager_emit_removed(m, &o->this);
 
 	object_destroy(o);
 }
@@ -689,10 +690,21 @@ static void on_core_done(void *data, uint32_t id, int seq)
 	}
 }
 
+static void on_core_error(void *data, uint32_t id, int seq, int res, const char *message)
+{
+	struct manager *m = data;
+
+	if (id == PW_ID_CORE && res == -EPIPE) {
+		pw_log_debug("connection error: %d, %s", res, message);
+		manager_emit_disconnect(m);
+	}
+}
+
 static const struct pw_core_events core_events = {
 	PW_VERSION_CORE_EVENTS,
 	.done = on_core_done,
 	.info = on_core_info,
+	.error = on_core_error
 };
 
 struct pw_manager *pw_manager_new(struct pw_core *core)
@@ -841,6 +853,14 @@ done:
 	return SPA_PTROFF(d, sizeof(struct object_data), void);
 }
 
+void *pw_manager_object_get_data(struct pw_manager_object *obj, const char *id)
+{
+	struct object *o = SPA_CONTAINER_OF(obj, struct object, this);
+	struct object_data *d = object_find_data(o, id);
+
+	return d ? SPA_PTROFF(d, sizeof(*d), void) : NULL;
+}
+
 int pw_manager_sync(struct pw_manager *manager)
 {
 	struct manager *m = SPA_CONTAINER_OF(manager, struct manager, this);
