@@ -48,6 +48,11 @@
 /** \page page_module_rtkit PipeWire Module: RTKit
  */
 
+#define NAME "rtkit"
+
+PW_LOG_TOPIC_STATIC(mod_topic, "mod." NAME);
+#define PW_LOG_TOPIC_DEFAULT mod_topic
+
 #define DEFAULT_NICE_LEVEL	-11
 #define DEFAULT_RT_PRIO		88
 #define DEFAULT_RT_TIME_SOFT	2000000
@@ -492,19 +497,6 @@ static int set_rlimit(struct impl *impl)
 	return res;
 }
 
-static int get_default_int(struct pw_properties *properties, const char *name, int def)
-{
-	int val;
-	const char *str;
-	if ((str = pw_properties_get(properties, name)) != NULL)
-		val = atoi(str);
-	else {
-		val = def;
-		pw_properties_setf(properties, name, "%d", val);
-	}
-	return val;
-}
-
 static struct thread *find_thread_by_pt(struct impl *impl, pthread_t pt)
 {
 	struct thread *t;
@@ -675,6 +667,8 @@ int pipewire__module_init(struct pw_impl_module *module, const char *args)
 	const char *str;
 	int res;
 
+	PW_LOG_TOPIC_INIT(mod_topic);
+
 	if ((props = pw_context_get_properties(context)) != NULL &&
 	    (str = pw_properties_get(props, "support.dbus")) != NULL &&
 	    !pw_properties_parse_bool(str))
@@ -703,13 +697,13 @@ int pipewire__module_init(struct pw_impl_module *module, const char *args)
 		pw_log_warn("could not get system bus: %m");
 		goto error;
 	}
-	impl->nice_level = get_default_int(impl->props, "nice.level", DEFAULT_NICE_LEVEL);
+	impl->nice_level = pw_properties_get_int32(impl->props, "nice.level", DEFAULT_NICE_LEVEL);
 
 	set_nice(impl, impl->nice_level);
 
-	impl->rt_prio = get_default_int(impl->props, "rt.prio", DEFAULT_RT_PRIO);
-	impl->rt_time_soft = get_default_int(impl->props, "rt.time.soft", DEFAULT_RT_TIME_SOFT);
-	impl->rt_time_hard = get_default_int(impl->props, "rt.time.hard", DEFAULT_RT_TIME_HARD);
+	impl->rt_prio = pw_properties_get_int32(impl->props, "rt.prio", DEFAULT_RT_PRIO);
+	impl->rt_time_soft = pw_properties_get_int32(impl->props, "rt.time.soft", DEFAULT_RT_TIME_SOFT);
+	impl->rt_time_hard = pw_properties_get_int32(impl->props, "rt.time.hard", DEFAULT_RT_TIME_HARD);
 
 	set_rlimit(impl);
 
